
# pzhive
support hive zookeeper HA mode(based on pyhive and kazoo)

# requirements
kazoo
pyhive


# example

    from pzhive import pzhive
    
    cursor = pzhive.connect_by_zk(zk_url="zk_host:2181",
                                  zk_name_space="name_space",
                                  auth="KERBEROS",
                                  configuration={"hive.server2.proxy.user": "hadoop"},
                                  kerberos_service_name="hive",
                                  kerberos_service_host="xxx",
                                  database="default")
    
    cursor.execute("show tables")
    print(cursor.fetchall())
    
